==> opennms-dao-mock-21.1.0-20200508.203733-136-sources.jar: org/opennms/netmgt/dao/mock/MockInterfaceToNodeCache.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.net.InetAddress;
import java.util.Collections;

import org.opennms.netmgt.dao.api.InterfaceToNodeCache;

public class MockInterfaceToNodeCache implements InterfaceToNodeCache {

    @Override
    public boolean setNodeId(String location, InetAddress ipAddr, int nodeId) {
        return false;
    }

    @Override
    public boolean removeNodeId(String location, InetAddress ipAddr, int nodeId) {
        return false;
    }

    @Override
    public Iterable<Integer> getNodeId(String location, InetAddress ipAddr) {
        return Collections.emptySet();
    }

    @Override
    public void dataSourceSync() {}

    @Override
    public int size() { return 1; }

    @Override
    public void clear() {}
}

==> opennms-dao-mock-22.0.0-20171114.065902-26-sources.jar: org/opennms/netmgt/dao/mock/MockInterfaceToNodeCache.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.net.InetAddress;
import java.util.Collections;

import org.opennms.netmgt.dao.api.AbstractInterfaceToNodeCache;

public class MockInterfaceToNodeCache extends AbstractInterfaceToNodeCache {

    @Override
    public boolean setNodeId(String location, InetAddress ipAddr, int nodeId) {
        return false;
    }

    @Override
    public boolean removeNodeId(String location, InetAddress ipAddr, int nodeId) {
        return false;
    }

    @Override
    public Iterable<Integer> getNodeId(String location, InetAddress ipAddr) {
        return Collections.emptySet();
    }

    @Override
    public void dataSourceSync() {}

    @Override
    public int size() { return 1; }

    @Override
    public void clear() {}
}
